package dev.kske.chess.ui;

import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.UnsupportedFlavorException;
import java.awt.dnd.DnDConstants;
import java.awt.dnd.DropTargetAdapter;
import java.awt.dnd.DropTargetDropEvent;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.util.List;

/**
 * Project: <strong>Chess</strong><br>
 * File: <strong>FENDropTarget.java</strong><br>
 * Created: <strong>13 Aug 2019</strong><br>
 * Author: <strong>Kai S. K. Engelbart</strong>
 */
public class FENDropTarget extends DropTargetAdapter {

	private GamePane gamePane;

	public FENDropTarget(GamePane gamePane) {
		this.gamePane = gamePane;
	}

	@Override
	public void drop(DropTargetDropEvent evt) {
		try {
			evt.acceptDrop(DnDConstants.ACTION_COPY_OR_MOVE);
			@SuppressWarnings(
				"unchecked"
			)
			List<File> droppedFiles = (List<File>) evt.getTransferable().getTransferData(DataFlavor.javaFileListFlavor);
			try (BufferedReader br = new BufferedReader(new FileReader(droppedFiles.get(0)))) {
				gamePane.getGame().reset();
				gamePane.getGame().getBoard().initFromFEN(br.readLine());
				gamePane.getBoardPane().getBoardComponent().repaint();
				gamePane.getGame()
					.getPlayers()
					.get(gamePane.getGame().getBoard().getLog().getActiveColor())
					.requestMove();
				evt.dropComplete(true);
			}
		} catch (UnsupportedFlavorException | IOException ex) {
			ex.printStackTrace();
			evt.rejectDrop();
		}
	}
}
